nikola.plugins.misc package
===========================

.. automodule:: nikola.plugins.misc
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

nikola.plugins.misc.scan\_posts module
--------------------------------------

.. automodule:: nikola.plugins.misc.scan_posts
   :members:
   :undoc-members:
   :show-inheritance:

nikola.plugins.misc.taxonomies\_classifier module
-------------------------------------------------

.. automodule:: nikola.plugins.misc.taxonomies_classifier
   :members:
   :undoc-members:
   :show-inheritance:
